@@ -20,6 +20,7 @@ import (
 	"github.com/abiosoft/colima/environment/container/docker"
 	"github.com/abiosoft/colima/environment/container/kubernetes"
 	"github.com/abiosoft/colima/util"
+	"github.com/abiosoft/colima/util/osutil"
 	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
@@ -58,16 +59,11 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 		}
 
 		// edit flag is specified
-		err := editConfigFile()
+		conf, err := editConfigFile()
 		if err != nil {
 			return err
 		}
 
-		conf, err = configmanager.Load()
-		if err != nil {
-			return fmt.Errorf("error opening config file: %w", err)
-		}
-
 		// validate config
 		if err := configmanager.ValidateConfig(conf); err != nil {
 			return fmt.Errorf("error in config file: %w", err)
@@ -100,9 +96,11 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 			return fmt.Errorf("error in config: %w", err)
 		}
 
-		// persist in preparing of application start
-		if err := configmanager.Save(startCmdArgs.Config); err != nil {
-			return fmt.Errorf("error preparing config file: %w", err)
+		// persist in preparation for application start
+		if startCmdArgs.Flags.SaveConfig {
+			if err := configmanager.Save(startCmdArgs.Config); err != nil {
+				return fmt.Errorf("error preparing config file: %w", err)
+			}
 		}
 
 		return nil
@@ -121,6 +119,7 @@ const (
 )
 
 var defaultK3sArgs = []string{"--disable=traefik"}
+var envSaveConfig = osutil.EnvVar("COLIMA_SAVE_CONFIG")
 
 var startCmdArgs struct {
 	config.Config
@@ -134,6 +133,7 @@ var startCmdArgs struct {
 		ActivateRuntime         bool
 		DNSHosts                []string
 		Foreground              bool
+		SaveConfig              bool
 	}
 }
 
@@ -144,6 +144,11 @@ func init() {
 	mounts := strings.Join([]string{defaultMountTypeQEMU, "9p", "virtiofs"}, ", ")
 	types := strings.Join([]string{defaultVMType, "vz"}, ", ")
 
+	saveConfigDefault := true
+	if envSaveConfig.Exists() {
+		saveConfigDefault = envSaveConfig.Bool()
+	}
+
 	root.Cmd().AddCommand(startCmd)
 	startCmd.Flags().StringVarP(&startCmdArgs.Runtime, "runtime", "r", docker.Name, "container runtime ("+runtimes+")")
 	startCmd.Flags().BoolVar(&startCmdArgs.Flags.ActivateRuntime, "activate", true, "set as active Docker/Kubernetes context on startup")
@@ -180,6 +185,7 @@ func init() {
 	// config
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Edit, "edit", "e", false, "edit the configuration file before starting")
 	startCmd.Flags().StringVar(&startCmdArgs.Flags.Editor, "editor", "", `editor to use for edit e.g. vim, nano, code (default "$EDITOR" env var)`)
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.SaveConfig, "save-config", saveConfigDefault, "persist and overwrite config file with (newly) specified flags")
 
 	// mounts
 	startCmd.Flags().StringSliceVarP(&startCmdArgs.Flags.Mounts, "mount", "V", nil, "directories to mount, suffix ':w' for writable")
@@ -468,11 +474,13 @@ func prepareConfig(cmd *cobra.Command) {
 }
 
 // editConfigFile launches an editor to edit the config file.
-func editConfigFile() error {
+func editConfigFile() (config.Config, error) {
+	var c config.Config
+
 	// preserve the current file in case the user terminates
 	currentFile, err := os.ReadFile(config.CurrentProfile().File())
 	if err != nil {
-		return fmt.Errorf("error reading config file: %w", err)
+		return c, fmt.Errorf("error reading config file: %w", err)
 	}
 
 	// prepend the config file with termination instruction
@@ -483,18 +491,23 @@ func editConfigFile() error {
 
 	tmpFile, err := waitForUserEdit(startCmdArgs.Flags.Editor, []byte(abort+"\n"+string(currentFile)))
 	if err != nil {
-		return fmt.Errorf("error editing config file: %w", err)
+		return c, fmt.Errorf("error editing config file: %w", err)
 	}
 
 	// if file is empty, abort
 	if tmpFile == "" {
-		return fmt.Errorf("empty file, startup aborted")
+		return c, fmt.Errorf("empty file, startup aborted")
 	}
 
 	defer func() {
 		_ = os.Remove(tmpFile)
 	}()
-	return configmanager.SaveFromFile(tmpFile)
+	if startCmdArgs.Flags.SaveConfig {
+		if err := configmanager.SaveFromFile(tmpFile); err != nil {
+			return c, err
+		}
+	}
+	return configmanager.LoadFrom(tmpFile)
 }
 
 func start(app app.App, conf config.Config) error {
@@ -508,14 +521,18 @@ func start(app app.App, conf config.Config) error {
 }
 
 func awaitForInterruption(app app.App) error {
-	signalChannel := make(chan os.Signal, 1)
-	signal.Notify(signalChannel, os.Interrupt, syscall.SIGINT, syscall.SIGTERM)
+	c := make(chan os.Signal, 1)
+	signal.Notify(c, os.Interrupt, syscall.SIGINT, syscall.SIGTERM)
+
 	log.Println("keeping Colima in the foreground, press ctrl+c to exit...")
-	sig := <-signalChannel
+
+	sig := <-c
 	log.Infof("interrupted by: %v", sig)
+
 	if err := app.Stop(false); err != nil {
 		log.Errorf("error stopping: %v", err)
 		return err
 	}
+
 	return nil
 }
