@@ -14,8 +14,10 @@ import (
 // Name is container runtime name
 const Name = "containerd"
 
+var configDir = func() string { return config.CurrentProfile().ConfigDir() }
+
 // HostSocketFile returns the path to the containerd socket on host.
-func HostSocketFile() string { return filepath.Join(config.Dir(), "containerd.sock") }
+func HostSocketFile() string { return filepath.Join(configDir(), "containerd.sock") }
 
 // This is written with assumption that Lima is the VM,
 // which provides nerdctl/containerd support out of the box.
@@ -51,11 +53,6 @@ func (c containerdRuntime) Name() string {
 }
 
 func (c containerdRuntime) Provision(context.Context) error {
-	if err := c.guest.RunQuiet("sh", "-c",
-		`sudo sed -i '/disabled_plugins =/c\disabled_plugins = []' /etc/containerd/config.toml`,
-	); err != nil {
-		return err
-	}
 	return c.guest.Write(buildKitConfFile, buildKitConf)
 }
 
