@@ -17,6 +17,7 @@ import (
 	"github.com/abiosoft/colima/environment/container/docker"
 	"github.com/abiosoft/colima/environment/container/incus"
 	"github.com/abiosoft/colima/environment/vm/lima/limaconfig"
+	"github.com/abiosoft/colima/environment/vm/lima/limautil"
 	"github.com/abiosoft/colima/util"
 	"github.com/sirupsen/logrus"
 )
@@ -132,8 +133,17 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 			if l.VMType == limaconfig.VZ {
 				l.Networks = append(l.Networks, limaconfig.Network{
 					VZNAT:     true,
-					Interface: vmnet.NetInterface,
+					Interface: limautil.NetInterface,
 				})
+				// special case for incus runtime
+				if conf.Runtime == incus.Name {
+					for i := 1; i < limautil.VZNetworksMaxNo; i++ {
+						l.Networks = append(l.Networks, limaconfig.Network{
+							VZNAT:     true,
+							Interface: limautil.NetInterfaceName(i),
+						})
+					}
+				}
 			} else {
 				reachableIPAddress, _ = ctx.Value(daemon.CtxKey(vmnet.Name)).(bool)
 
@@ -148,9 +158,19 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 
 						l.Networks = append(l.Networks, limaconfig.Network{
 							Socket:    socketFile,
-							Interface: vmnet.NetInterface,
+							Interface: limautil.NetInterface,
 						})
 
+						// special case for incus runtime
+						if conf.Runtime == incus.Name {
+							for i := 1; i < limautil.VZNetworksMaxNo; i++ {
+								l.Networks = append(l.Networks, limaconfig.Network{
+									Socket:    socketFile,
+									Interface: limautil.NetInterfaceName(i),
+								})
+							}
+						}
+
 						return nil
 					}(); err != nil {
 						reachableIPAddress = false
@@ -179,6 +199,27 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 					},
 				)
 			}
+
+			// disable port forwarding for Incus when there is a reachable IP address for consistent behaviour
+			if reachableIPAddress && conf.Runtime == incus.Name {
+				l.PortForwards = append(l.PortForwards,
+					limaconfig.PortForward{
+						GuestIP:           net.ParseIP("0.0.0.0"),
+						GuestIPMustBeZero: true,
+						GuestPortRange:    [2]int{1, 65535},
+						HostPortRange:     [2]int{1, 65535},
+						Ignore:            true,
+						Proto:             limaconfig.TCP,
+					},
+					limaconfig.PortForward{
+						GuestIP:        net.ParseIP("127.0.0.1"),
+						GuestPortRange: [2]int{1, 65535},
+						HostPortRange:  [2]int{1, 65535},
+						Ignore:         true,
+						Proto:          limaconfig.TCP,
+					},
+				)
+			}
 		}
 	}
 
